﻿using BA.API;
using BA.Core.Configuration.FormBase;
using BA.Core.Configuration.FormBase.Controls;
using BA.Core.Configuration.FormBase.Controls.Layout;
using BA.Core.Configuration.Grid;
using BA.Core.Configuration.Grid.Columns;
using BA.Core.CustomAttributes;
using BA.Core.CustomAttributes.Validations;
using BA.Core.Dialogs;
using BA.Core.Enums;
using BA.Core.Models;
using $safeprojectname$.DataProvider;
using DevExpress.Web.Mvc;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace $safeprojectname$.Dialoge
{
    public class AddServiceDialogModel
    {
        [BARequired]
        public string Remark { get; set; }

        public string Test { get; set; }

        [BARequired]
        public DateTime Date { get; set; }
    }

    [DialogImplementation("$safeprojectname$.AddServiceDialog")]
    public class AddServiceDialog : DialogImplementationBase
    {
        /// <summary>
        /// Gridkonfigurations GUID
        /// </summary>
        private readonly Guid EngineGridConfigGuid = "70F3ADB8-41C8-4484-A77A-63A67E444A7F".ToGuid();

        /// <inheritdoc/>
        public override void CreateDialogContent(DevExFormModel formModel, HttpRequestBase request, ModelStateDictionary modelState, Dictionary<String, Object> parameter, object bindObject = null)
        {
            // Bei einem neuen Dialog ist das bindObject NULL
            AddServiceDialogModel dataModel;
            if (bindObject == null)
                dataModel = new AddServiceDialogModel { Date = DateTime.Now, Remark = parameter.Get("RemarkMessage")?.ToString() };
            else
                dataModel = (AddServiceDialogModel)bindObject;

            // Formmodel Basis
            formModel.Title = "95437073-8D05-4650-8F75-4B53AEB4A456".Translate();
            formModel.DataSource = dataModel;
            formModel.Width = 600;

            LayoutPanelControl layout = new LayoutPanelControl()
            {
                Id = "DEB77CD6-1823-445F-A70D-A0E6001E4351".ToGuid(),
                ColumnCount = 2,
                WrapContentAtWidth = 400,
            };
            layout.AddBreakpoint(new BreakpointRule() { Name = "S", ColumnCount = 1, MaxWidth = 500 });
            Controls.Add(layout);

            // Datumsfeld
            DateEditControl dateTime = new DateEditControl()
            {
                Id = "70C9B90B-832C-460A-9A9F-E83463C0CC1F".ToGuid(),
                Caption = "B2A43538-EF7C-416F-89AB-F501D09AE6E3",
                ShowTimeSection = false,
                ColSpan = 1,
                OrmFieldName = nameof(AddServiceDialogModel.Date)
            };
            layout.Controls.Add(dateTime);

            // Textfeld
            TextEditControl textControl = new TextEditControl()
            {
                Id = "6DF2D790-8710-4A69-9530-49DAA3F31B36".ToGuid(),
                Caption = "5D49A7FE-8165-4FDC-953F-A194BCFFCE26",
                ColSpan = 1,
                OrmFieldName = nameof(AddServiceDialogModel.Remark)
            };
            layout.Controls.Add(textControl);

            // Leeres control für den Abstand
            EmptyControl emptyControl = new EmptyControl()
            {
                Id = "C5717528-E99A-4371-B058-376CBC27B1EB".ToGuid(),
                ColSpan = 2,
            };
            layout.Controls.Add(emptyControl);

            // Dynamische Gridkonfiguration.
            CreateGridConfiguration();

            // Ansicht im Dialog. In diesem Falls mit einer dynamischen Gridkonfiguration und einem eigenen Datenprovider
            // Als Gridkonfiguration wird häufig eine Konfigurierte genommen.
            GridInDialogControl gridControl = new GridInDialogControl()
            {
                Id = "6DF2D790-8710-4A69-9530-49DAA3F31B36".ToGuid(),
                ColSpan = 2,
                GridConfigurationGuid = EngineGridConfigGuid.ToString(),
            };
            layout.Controls.Add(gridControl);

            // Buttons
            formModel.AddButton("$safeprojectname$.InputButton", "5d49a7fe-8165-4fdc-953f-a194bcffce26".Translate(), false, "$safeprojectname$.Actions.InputButton");
            formModel.AddButton(DialogButtonIds.OkButton, "OK", true);
            formModel.AddButton(DialogButtonIds.CancelButton, "Cancel", false, "BA.Ui.Dialog.DialogManager.DialogDefaultCancel");
        }

        /// <summary>
        /// Dynamische Gridkonfiguration. Wird zur Laufzeit angelegt.
        /// </summary>
        private void CreateGridConfiguration()
        {
            if (!Api.Config.ContainsKey(EngineGridConfigGuid))
            {
                // Ansichtenkonfiguration erstellen
                GridViewConfiguration engineGrid = new GridViewConfiguration()
                {
                    Id = EngineGridConfigGuid,
                    ConfigurationName = "EngineGridInDialog",
                    // Spaltennamen sollen dem Modelnamen entsprechen. Kein automatisches unique machen der Spaltennamen
                    UseSourceColumns = true,
                    ShowSearchPanel = false,
                    ShowFilterRowForColummns = false,

                    DataProviderProperties = new GDPEnginesProperties()
                    {
                        WithReadPermissions = false,
                        ResponsibleNotContains = "Andreas",
                    }
                };

                // Konfiguraion initialisieren
                engineGrid.Initialize();

                // Drei Spalten hinzufügen
                engineGrid.FloatingColumns.Columns.Add(new TextBoxColumn()
                {
                    OrmFieldName = nameof(GridResponsibleRowModel.Name),
                    Caption = "Name"
                });
                engineGrid.FloatingColumns.Columns.Add(new TextBoxColumn()
                {
                    OrmFieldName = nameof(GridResponsibleRowModel.ResponsibleText),
                    Caption = "Betreuer (Text)"
                });
                engineGrid.FloatingColumns.Columns.Add(new TextBoxColumn()
                {
                    OrmFieldName = nameof(GridResponsibleRowModel.ResponsibleRelationLINQ),
                    Caption = "Betreuer (Relation über LINQ)"
                });
                engineGrid.FloatingColumns.Columns.Add(new TextBoxColumn()
                {
                    OrmFieldName = nameof(GridResponsibleRowModel.ResponsibleRelationFormula),
                    Caption = "Betreuer (Relation über Formel)"
                });

                Api.Config.RefreshSingleConfigurationCache(engineGrid);
            }
        }

        /// <inheritdoc/>
        public override DialogResultModel HandleAction(HttpRequestBase request, ModelStateDictionary modelState, Dictionary<String, Object> parameter, String buttonId, object bindObject, string propertyPrefix = "")
        {
            DialogResultModel result = base.HandleAction(request, modelState, parameter, buttonId, bindObject, propertyPrefix);
            if (buttonId == DialogButtonIds.OkButton && modelState.IsValid)
            {
                AddServiceDialogModel dataModel = (AddServiceDialogModel)bindObject;
                result.Data = dataModel;
            }

            return result;
        }
    }
}