﻿using BA.API;
using BA.Core.Enums;
using BA.Core.MassOperations.Igniters;
using BA.Core.Models;
using $safeprojectname$.DB;
using $safeprojectname$.Worker;
using DevExpress.Xpo;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace $safeprojectname$.Igniters
{
    public class AddServiceIgniter : OperationOverSelectedRecordsIgniterBase
    {
        public AddServiceIgniter(IgnitionModel ignitionModel) : base(ignitionModel)
        {
            AllRecordsIfNothingIsSelectedIndicator = false;
            CreateTemporaryRecordsIndicator = true;
            UniqueRecordListIndicator = true;
        }

        /// <inheritdoc/>
        public override ActionResult Ignite()
        {
            if (SomethingSelected)
            {
                // Prüfung ob eine Bemerkung übergeben wurde.
                if (IgnitionModel.Parameters.TryGetValue("RemarkMessage", out object remarkObj) && remarkObj is string remark && !string.IsNullOrWhiteSpace(remark))
                {
                    // Servicedatum setzen.
                    DateTime date;
                    if (IgnitionModel.Parameters.TryGetValue("ServiceDate", out object dateObj) && dateObj is DateTime)
                        date = (DateTime)dateObj;
                    else
                        date = DateTime.Now;

                    // Query erstellen
                    Session session = Api.ORM.GetNewSession();
                    IEnumerable<Guid> oids = Records.Select(ff => ff.Oid);
                    IQueryable<OrmEngine> engines = Api.ORM.GetQuery<OrmEngine>(session).Where(ff => oids.Contains(ff.Oid));

                    // Verarbeitung
                    int successful = 0;
                    int missingRights = 0;
                    foreach (OrmEngine engine in engines)
                    {
                        if (engine.IsAllowed(EnumTableOperations.Edit))
                        {
                            // Service Teil-Datensatz hinzufügen
                            OrmSubEngineServices service = engine.Services.AddNewObject();
                            service.SortOrder = engine.Services.Count() - 1;
                            service.ServiceDate = date;
                            service.Remark = remark;
                            engine.Save();
                            successful++;
                        }
                        else
                            missingRights++;
                    }

                    // Benutzer informieren
                    if (missingRights == 0)
                        Api.ClientCommunication.CreateSuccess(Api.User.CurrentUserGuid(), "dd1ceadc-6808-4583-b6b7-dda73188b5a8".Translate(successful));
                    else
                        Api.ClientCommunication.CreateInfo(Api.User.CurrentUserGuid(), "e3f652e7-8019-4444-9e6c-f3c30528e862".Translate(successful, missingRights));

                    // Beenden und die Ansicht aktualisieren
                    return new JsonResult() { Data = new JsonFormResult() { RefreshGrid = true } };
                }
                else
                    Api.ClientCommunication.CreateError(Api.User.CurrentUserGuid(), "d49ef787-3ad1-4f66-bb12-b2660fd71738".Translate());
            }

            return null;
        }
    }
}