declare module BA.Ui.Dialog {
    class OrmDialogManager {
        /**
         * List of events that need to be executed on successful SubmitOrm call
         */
        private static onSuccessEvents;
        /**
         * This function is meant to be used by a orm dialog user in order to invoke a orm dialog by form dialog model.
         * Whatever the user passes as the additionalData parameter will be returned as second
         * parameter on the given onClose function. The first parameter of that onClose function will be the
         * DialogResult which contains all the information which the dialog user hoped to retrieve from calling
         * this dialog.
         *
         * @param ormFormDialog the form dialog model, to specify the orm dialog behaviour
         * @param customData data that will be routed through the dialog and passed to the onClose function
         * @param onClose function that will be called when the dialog closes; parameter 1 will be the DialogResult,
         *              parameter 2 will be the additionalData
         */
        static OpenDialog(ormFormDialog: BA.Ui.Models.FormDialogModel, customData?: CustomData, onClose?: Function): void;
        /**
         * This function is meant to be used by a orm dialog user in order to invoke a orm dialog by record id and optional form id.
         * Whatever the user passes as the additionalData parameter will be returned as second
         * parameter on the given onClose function. The first parameter of that onClose function will be the
         * DialogResult which contains all the information which the dialog user hoped to retrieve from calling
         * this dialog.
         *
         * @param recordId the record id
         * @param formId the form id. Can be NULL
         * @param customData data that will be routed through the dialog and passed to the onClose function
         * @param onClose function that will be called when the dialog closes; parameter 1 will be the DialogResult,
         *              parameter 2 will be the additionalData
         */
        static OpenDialogByOid(recordId: BA.Classes.Guid | string, formId?: BA.Classes.Guid | string, customData?: CustomData, onClose?: Function): void;
        /**
         * Submits the form to the server. The orm will be saved if it is valid.
         * @param button The pressed dialog button
         * @param evt The event object
         * @param onSubmit function that will be executed upon success
         */
        static SubmitOrm(button: BADialogButton, evt: ASPxClientButtonClickEventArgs, onSubmit?: Function): void;
        /**
         * Method executed after the popup is opened and the form is shown
         * @param popup The popup
         */
        static OnOpenMethod(popup: BADialogPopup): void;
        private static _DoOnOpenEvent;
        static OnResize(s: any, e: any): void;
        static CloseLoadingAnimation(): void;
        /**
         * The ajax submit on success default handling
         * @param data The data object
         * @param status The return status
         * @param xhr The xhr object
         */
        static PopupFormSuccess(data: any, status: any, xhr: any, dialogLevel?: number): void;
        /**
         * The action to restore the orm in the dialog.
         * @param window The context window
         * @param button The pressed dialog button
         * @param evt The event object
         */
        static RestoreOrm(button: BADialogButton, evt: ASPxClientButtonClickEventArgs): void;
        /**
         * The action to delete the orm in the dialog.
         * @param window The context window
         * @param button The pressed dialog button
         * @param evt The event object
         */
        static DeleteOrm(button: BADialogButton, evt: ASPxClientButtonClickEventArgs): void;
    }
}
